@@ -12,11 +12,11 @@ class ESDocument(BaseModel):
     type: doc_fields.Type
     uri: str
     format: Optional[doc_fields.Type]
-    modified: Optional[str]
-    issued: Optional[str]
+    modified: Optional[str] = None
+    issued: Optional[str] = None
     periodicity: Optional[str] = ""
     provenance: Optional[str] = "NAV"
-    contactpoint: Optional[str] = {}
+    contactPoint: Optional[dict] = {}
     author: Optional[str] = ""
     repo: Optional[str] = ""
     readme: Optional[str] = ""
